@@ -15,8 +15,8 @@ namespace net
 {
 class SocketMonitor;
 
-/**
-    @author Joris Guisson <joris.guisson@gmail.com>
+/*!
+    \author Joris Guisson <joris.guisson@gmail.com>
 */
 class UploadThread : public NetworkThread
 {
@@ -29,27 +29,27 @@ public:
     UploadThread(SocketMonitor *sm);
     ~UploadThread() override;
 
-    /// Wake up thread, data is ready to be sent
+    //! Wake up thread, data is ready to be sent
     void signalDataReady();
 
-    /// Set the upload cap
+    //! Set the upload cap
     static void setCap(bt::Uint32 uc)
     {
         ucap = uc;
     }
 
-    /// Get the upload cap
-    static Uint32 cap()
+    //! Get the upload cap
+    static bt::Uint32 cap()
     {
         return ucap;
     }
 
-    /// Set the sleep time when using upload caps
+    //! Set the sleep time when using upload caps
     static void setSleepTime(bt::Uint32 stime);
 
 private:
     void update() override;
-    bool doGroup(SocketGroup *g, Uint32 &allowance, bt::TimeStamp now) override;
+    bool doGroup(SocketGroup *g, bt::Uint32 &allowance, bt::TimeStamp now) override;
 
     int waitForSocketsReady();
 };
